@@ -191,10 +191,30 @@ plugin_show_infoprint(gchar * msg)
 
 /**
   Restores the last selected settings, which was selected by the user before continue the game
+  The fresh changes against the original ones should not be updated using
+  previous user selected ones.
 */
 static void
 plugin_restore_last_settings(void)
 {
+    gint original_difficulty =
+        gconf_client_get_int(gcc, DIFFICULTY_LEVEL, NULL);
+    gint original_noise = gconf_client_get_int(gcc, NOISE_LEVEL, NULL);
+    gint original_height = gconf_client_get_int(gcc, NOISE_HEIGHT, NULL);
+    gint current_difficulty =
+        gtk_combo_box_get_active(GTK_COMBO_BOX(difficult_box));
+    gint current_noise =
+        gtk_combo_box_get_active(GTK_COMBO_BOX(noise_level_box));
+    gint current_height =
+        gtk_combo_box_get_active(GTK_COMBO_BOX(noise_height_box));
+
+    if (original_difficulty != current_difficulty)
+        selected_difficulty = current_difficulty;
+    if (original_noise != current_noise)
+        selected_noise = current_noise;
+    if (original_height != current_height)
+        selected_height = current_height;
+
     if (selected_difficulty != -1)
     {
         gtk_combo_box_set_active(GTK_COMBO_BOX(difficult_box),
